@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw{Net::GPSD3::Return::Unknown};
 
-our $VERSION='0.02';
+our $VERSION='0.03';
 
 =head1 NAME
 
@@ -13,12 +13,28 @@ Net::GPSD3::Return::ERROR - Net::GPSD3 Return ERROR Object
 
 =head1 DESCRIPTION
 
-=head1 CONSTRUCTOR
-
-=head2 new
-
 =head1 METHODS
 
+=head2 class
+
+Returns the object class
+
+=head2 string
+
+Returns the JSON string
+
+=head2 parent
+
+Return the parent Net::GPSD object
+
+=head2 message
+
+Textual error message.
+
+=cut
+
+sub message {shift->{"message"}};
+
 =head1 BUGS
 
 Log on RT and Send to gpsd-dev email list
