@@ -3,17 +3,29 @@ use strict;
 use warnings;
 use base qw{Net::GPSD3::Return::Unknown};
 
-our $VERSION='0.02';
+our $VERSION='0.03';
 
 =head1 NAME
 
-Net::GPSD3::Return::Satellite - Net::GPSD3 Return Object Satellite Class
+Net::GPSD3::Return::Satellite - Net::GPSD3 Return Satellite Object
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-=head1 METHODS PROPERTIES
+=head1 METHODS
+
+=head2 class
+
+Returns the object class
+
+=head2 string
+
+Returns the JSON string
+
+=head2 parent
+
+Return the parent Net::GPSD object
 
 =head2 PRN
 
