@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw{Net::GPSD3::Return::Unknown};
 
-our $VERSION='0.01';
+our $VERSION='0.03';
 
 =head1 NAME
 
@@ -15,6 +15,18 @@ Net::GPSD3::Return::WATCH - Net::GPSD3 Return WATCH Object
 
 =head1 METHODS
 
+=head2 class
+
+Returns the object class
+
+=head2 string
+
+Returns the JSON string
+
+=head2 parent
+
+Return the parent Net::GPSD object
+
 =head2 enable
 
 =cut
